# Changelog

<!--next-version-placeholder-->

## v1.0.1 (2021-04-18)
### Fix
* Aiohttp>=3.7.4 ([`7fdb446`](https://github.com/eifinger/aioweenect/commit/7fdb4464c477f3973f1e0d19609cf91b3bcc0c68))

## v1.0.0 (2021-04-15)
### Feature
* 1.0.0 ([`5dc20db`](https://github.com/eifinger/aioweenect/commit/5dc20db1399aaad5b3f0efab20a66a9c149dc8b7))

### Breaking
* First Release  ([`5dc20db`](https://github.com/eifinger/aioweenect/commit/5dc20db1399aaad5b3f0efab20a66a9c149dc8b7))
